Personalización
===============


Opciones del tema
-----------------

Puedes utilizar la variable ``html_theme_options`` dentro de ``conf.py``
para configurar ciertas opciones del tema.

Esenciales
^^^^^^^^^^

Utilizadas para ciertos enlaces y el pie de página.

* ``description``: Una explicación corta del proyecto.
* ``github_repo``: Repositorio de GitHub del proyecto.
* ``github_user``: Usuario de GitHub del proyecto.
* ``extra_nav_links``: Enlaces adicionales relacionados.

Redes Sociales
^^^^^^^^^^^^^^

Atajos para insertar enlaces a tus perfiles de redes sociales en el
pie de página. Solo debes especificar tu *handle* o nombre de usuario.

* ``twitter_user``
* ``youtube_user``
* ``instagram_user``
